# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from .._models import BaseModel

__all__ = ["SpeechTranscribeResponse", "Segment"]


class Segment(BaseModel):
    end: Optional[int] = None

    speaker: Optional[int] = None

    start: Optional[int] = None

    text: Optional[int] = None


class SpeechTranscribeResponse(BaseModel):
    request_id: str

    segments: Optional[List[Optional[Segment]]] = None

    text: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, TypedDict

__all__ = ["SpeechGenerateParams"]


class SpeechGenerateParams(TypedDict, total=False):
    language: Required[Literal["yo", "en", "ha", "ig"]]

    text: Required[str]

    voice: Required[
        Literal[
            "sade",
            "segun",
            "femi",
            "funmi",
            "amina",
            "aliyu",
            "hasan",
            "zainab",
            "ngozi",
            "amara",
            "ebuka",
            "obinna",
            "lucy",
            "lina",
            "john",
            "jude",
            "henry",
            "kani",
        ]
    ]

    stream: bool



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .text_tone_mark_params import TextToneMarkParams as TextToneMarkParams
from .text_translate_params import TextTranslateParams as TextTranslateParams
from .speech_generate_params import SpeechGenerateParams as SpeechGenerateParams
from .text_tone_mark_response import TextToneMarkResponse as TextToneMarkResponse
from .text_translate_response import TextTranslateResponse as TextTranslateResponse
from .speech_transcribe_params import SpeechTranscribeParams as SpeechTranscribeParams
from .speech_transcribe_response import SpeechTranscribeResponse as SpeechTranscribeResponse
